@@ -1,5 +1,5 @@
 /* GNOME-DB Components
- * Copyright (C) 2000 - 2005 The GNOME Foundation.
+ * Copyright (C) 2000 - 2007 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -25,8 +25,6 @@
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkstock.h>
 #include <libgnomedb/libgnomedb.h>
-#include <libgnomeui/gnome-client.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtknotebook.h>
 #include <libgnomedb/gnome-db-util.h>
@@ -41,48 +39,40 @@ GtkActionGroup *actions;
 #define PROVIDER_PAGE "Provider_Page"
 static GtkWidget *create_main_notebook (void);
 
+#ifdef HAVE_GTKTWOTEN
 static void
-druid_finished_cb (GnomeDbDsnConfigDruid *druid, gboolean error, gpointer user_data)
+assistant_finished_cb (GnomeDbDsnAssistant *assistant, gboolean error, gpointer user_data)
 {
 	const GdaDataSourceInfo *dsn_info;
 
 	if (!error) {
-		dsn_info = gnome_db_dsn_config_druid_get_dsn (druid);
+		dsn_info = gnome_db_dsn_assistant_get_dsn (assistant);
 		if (dsn_info)
 			gda_config_save_data_source_info (dsn_info);
 		else
 			gnome_db_show_error (NULL, _("No valid data source info was created"));
 	}
+}
 
-	gtk_widget_destroy (GTK_WIDGET (user_data));
+static void
+assistant_closed_cb (GnomeDbDsnAssistant *assistant, gpointer user_data)
+{
+	gtk_widget_destroy (GTK_WIDGET (assistant));
 }
 
 static void
 file_new_cb (GtkAction *action, gpointer user_data)
 {
-	GtkWidget *druid, *dialog;
-	GdkPixbuf *icon;
+	GtkWidget *assistant;
 
-	/* create the window to contain the druid */
-	dialog = gtk_dialog_new_with_buttons (_("New data source"), GTK_WINDOW (main_window),
-					      0, NULL);
-
-	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
-	if (icon) {
-		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
-		g_object_unref (icon);
-	}
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-
-	druid = gnome_db_dsn_config_druid_new ();
-	g_signal_connect (G_OBJECT (druid), "finished",
-			  G_CALLBACK (druid_finished_cb), dialog);
-	gtk_widget_show (druid);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), druid, TRUE, TRUE, 0);
-
-	/* run the dialog */
-	gtk_widget_show (dialog);
+	assistant = gnome_db_dsn_assistant_new ();
+	g_signal_connect (G_OBJECT (assistant), "finished",
+			  G_CALLBACK (assistant_finished_cb), NULL);
+	g_signal_connect (G_OBJECT (assistant), "close",
+			  G_CALLBACK (assistant_closed_cb), NULL);
+	gtk_widget_show (assistant);
 }
+#endif
 
 static void
 file_properties_cb (GtkAction *action, gpointer user_data)
@@ -174,7 +164,9 @@ about_cb (GtkAction *action, gpointer user_data)
 static GtkActionEntry ui_actions[] = {
 	{ "Database", NULL, "_Data source", NULL, "Database", NULL },
 	{ "DatabaseClose", GTK_STOCK_CLOSE, "_Close", NULL, "Close this window", G_CALLBACK (window_closed_cb) },
+#ifdef HAVE_GTKTWOTEN
 	{ "DatabaseNew", GTK_STOCK_NEW, "_New datasource", NULL, "Create new data source", G_CALLBACK (file_new_cb) },
+#endif
 	{ "DatabaseDelete", GTK_STOCK_DELETE, "_Delete datasource", NULL, "Delete selected data source", G_CALLBACK (file_delete_cb) },
 	{ "DatabaseProperties", GTK_STOCK_PROPERTIES, "_Properties", NULL, "Edit properties for selected data source", G_CALLBACK (file_properties_cb) },
 	{ "About", NULL, "_About", NULL, "About", NULL },
@@ -185,7 +177,9 @@ static const gchar *ui_actions_info =
         "<ui>"
 	"  <menubar name='MenuBar'>"
 	"    <menu name='Database' action='Database'>"
+#ifdef HAVE_GTKTWOTEN
 	"      <menuitem name='DatabaseNew' action= 'DatabaseNew'/>"
+#endif
 	"      <menuitem name='DatabaseProperties' action= 'DatabaseProperties'/>"
 	"      <menuitem name='DatabaseDelete' action= 'DatabaseDelete'/>"
 	"      <separator/>"
@@ -196,7 +190,9 @@ static const gchar *ui_actions_info =
 	"    </menu>"
 	"  </menubar>"
         "  <toolbar  name='ToolBar'>"
+#ifdef HAVE_GTKTWOTEN
         "    <toolitem action='DatabaseNew'/>"
+#endif
         "    <toolitem action='DatabaseProperties'/>"
         "    <toolitem action='DatabaseDelete'/>"
         "  </toolbar>"
@@ -273,18 +269,12 @@ create_main_window (gpointer user_data)
 int
 main (int argc, char *argv[])
 {
-	GnomeClient *session_client;
-
 	bindtextdomain (GETTEXT_PACKAGE, LIBGNOMEDB_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	gnome_db_init ("gnome-database-properties", PACKAGE_VERSION, argc, argv);
 
-	/* session management */
-	session_client = gnome_master_client ();
-	gnome_client_set_restart_style (session_client, GNOME_RESTART_NEVER);
-
 	/* application loop */
 	gnome_db_main_run ((GdaInitFunc) create_main_window, NULL);
 
