@@ -19,11 +19,14 @@
  * Authors:
  *   Daniel Espinosa Ortiz <esodan@gmail.com>
  */
-#include <glade.h>
-#include <glade-gtk.h>
+#include <gladeui/glade.h>
 #include <libgnomedb/libgnomedb.h>
 
-#define GLADEGNOMEDB_API GLADEGTK_API
+#ifdef G_OS_WIN32
+#define GLADEGNOMEDB_API __declspec(dllexport)
+#else
+#define GLADEGNOMEDB_API
+#endif
 
 /* This function does absolutely nothing
  * (and is for use in overriding post_create functions).
