@@ -28,6 +28,7 @@
 #include <libgnomedb/gnome-db-combo.h>
 #include <libgnomedb/gnome-db-data-entry.h>
 #include <libgnomedb/utility.h>
+#include <libgda/gda-enum-types.h>
 
 #define GNOME_DB_DATA_CELL_RENDERER_COMBO_PATH "gnome-db-data-cell-renderer-combo-path"
 
@@ -78,7 +79,10 @@ enum {
 	PROP_VALUES_DISPLAY,
 	PROP_VALUE_ATTRIBUTES,
 	PROP_TO_BE_DELETED,
-	PROP_SET_DEFAULT_IF_INVALID
+	PROP_SET_DEFAULT_IF_INVALID,
+	PROP_SHOW_EXPANDER,
+	PROP_PARAMLIST,
+	PROP_PARAMLISTSOURCE
 };
 
 struct _GnomeDbDataCellRendererComboPrivate
@@ -90,6 +94,7 @@ struct _GnomeDbDataCellRendererComboPrivate
 	guint                   attributes;
 	gboolean                to_be_deleted;
 	gboolean                set_default_if_invalid;
+	gboolean                show_expander;
 };
 
 
@@ -129,6 +134,7 @@ gnome_db_data_cell_renderer_combo_init (GnomeDbDataCellRendererCombo *datacell)
 	datacell->priv = g_new0 (GnomeDbDataCellRendererComboPrivate, 1);
 	datacell->priv->attributes = 0;
 	datacell->priv->set_default_if_invalid = FALSE;
+  datacell->priv->show_expander = TRUE;
 }
 
 static void
@@ -153,29 +159,42 @@ gnome_db_data_cell_renderer_combo_class_init (GnomeDbDataCellRendererComboClass
 					 PROP_VALUES,
 					 g_param_spec_pointer ("values",
 							       _("Values limited to PK fields"),
-							       _("GList of GdaValue to render, limited to PK fields"),
+							       _("GList of GValue to render, limited to PK fields"),
 							       G_PARAM_WRITABLE));
 	
 	g_object_class_install_property (object_class,
 					 PROP_VALUES_DISPLAY,
 					 g_param_spec_pointer ("values_display",
 							       _("Values"),
-							       _("GList of GdaValue to render, not limited to PK fields "),
+							       _("GList of GValue to render, not limited to PK fields "),
 							       G_PARAM_WRITABLE));
   
 	g_object_class_install_property (object_class,
 					 PROP_VALUE_ATTRIBUTES,
-					 g_param_spec_uint ("value_attributes", NULL, NULL,
-                                                            0, G_MAXUINT, 0, G_PARAM_READWRITE));
+					 g_param_spec_flags ("value_attributes", NULL, NULL, GDA_TYPE_VALUE_ATTRIBUTE,
+                                                            GDA_VALUE_ATTR_NONE, G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_TO_BE_DELETED,
 					 g_param_spec_boolean ("to_be_deleted", NULL, NULL, FALSE,
                                                                G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class,
+					 PROP_SHOW_EXPANDER,
+					 g_param_spec_boolean ("show_expander", NULL, NULL, FALSE,
+                                                               G_PARAM_WRITABLE));
 
-        g_object_class_install_property (object_class, PROP_SET_DEFAULT_IF_INVALID,
+	g_object_class_install_property (object_class, PROP_SET_DEFAULT_IF_INVALID,
 					 g_param_spec_boolean ("set_default_if_invalid", NULL, NULL, FALSE,
                                                                (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+  
+	g_object_class_install_property (object_class, PROP_PARAMLIST,
+					 g_param_spec_object ("param_list", NULL, NULL, GDA_TYPE_PARAMETER_LIST,
+                                                               (G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
+
+	/* Ideally, GdaParameterListSource would be a boxed type, but it is not yet, so we use g_param_spec_pointer(). */
+	g_object_class_install_property (object_class, PROP_PARAMLISTSOURCE,
+					 g_param_spec_pointer ("param_list_source", NULL, NULL,
+                                                               (G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE)));
 	  
 	text_cell_renderer_combo_signals [CHANGED] =
 		g_signal_new ("changed",
@@ -204,8 +223,10 @@ gnome_db_data_cell_renderer_combo_dispose (GObject *object)
 {
 	GnomeDbDataCellRendererCombo *datacell = GNOME_DB_DATA_CELL_RENDERER_COMBO (object);
 
-	if (datacell->priv->paramlist) 
+	if (datacell->priv->paramlist) {
 		paramlist_destroyed_cb (datacell->priv->paramlist, datacell);
+		datacell->priv->paramlist = NULL;
+	}
 
 	/* parent class */
 	parent_class->dispose (object);
@@ -236,7 +257,7 @@ gnome_db_data_cell_renderer_combo_get_property (GObject *object,
 
 	switch (param_id) {
 	case PROP_VALUE_ATTRIBUTES:
-		g_value_set_uint (value, datacell->priv->attributes);
+		g_value_set_flags (value, datacell->priv->attributes);
 		break;
 	case PROP_SET_DEFAULT_IF_INVALID:
 		g_value_set_boolean (value, datacell->priv->set_default_if_invalid);
@@ -271,7 +292,7 @@ gnome_db_data_cell_renderer_combo_set_property (GObject *object,
 					values = g_slist_append (values, gvalues->data);
 					
 					if (!gvalues->data || 
-					    (gvalues->data && !gda_value_is_null ((GdaValue *)(gvalues->data))))
+					    (gvalues->data && !gda_value_is_null ((GValue *)(gvalues->data))))
 					    allnull = FALSE;
 
 					length ++;
@@ -296,12 +317,12 @@ gnome_db_data_cell_renderer_combo_set_property (GObject *object,
 						gchar *str;
 						
 						for (i = 0; i < datacell->priv->source->shown_n_cols; i++) {
-							const GdaValue *value;
+							const GValue *value;
 							
 							value = gda_data_model_get_value_at (datacell->priv->source->data_model,
 											     datacell->priv->source->shown_cols_index [i],
 											     row);
-							dsplay_values = g_list_append (dsplay_values, (GdaValue *) value);
+							dsplay_values = g_list_append (dsplay_values, (GValue *) value);
 						}
 						str = render_text_to_display_from_values (dsplay_values);
 						g_list_free (dsplay_values);
@@ -329,7 +350,7 @@ gnome_db_data_cell_renderer_combo_set_property (GObject *object,
 	case PROP_VALUES_DISPLAY:
 		if (value) {
 			GList *gvalues = g_value_get_pointer (value);
-			GdaValue *value;
+			GValue *value;
 			gint i;
 			gchar *str;
 
@@ -344,14 +365,31 @@ gnome_db_data_cell_renderer_combo_set_property (GObject *object,
 		g_object_notify (object, "values_display");
 		break;
 	case PROP_VALUE_ATTRIBUTES:
-		datacell->priv->attributes = g_value_get_uint (value);
+		datacell->priv->attributes = g_value_get_flags (value);
 		break;
 	case PROP_TO_BE_DELETED:
 		datacell->priv->to_be_deleted = g_value_get_boolean (value);
 		break;
+	case PROP_SHOW_EXPANDER:
+		datacell->priv->show_expander = g_value_get_boolean (value);
+		break;
 	case PROP_SET_DEFAULT_IF_INVALID:
 		datacell->priv->set_default_if_invalid = g_value_get_boolean (value);
 		break;
+	case PROP_PARAMLIST:
+		if (datacell->priv->paramlist)
+			g_object_unref (datacell->priv->paramlist);
+
+		datacell->priv->paramlist = GDA_PARAMETER_LIST(g_value_get_object(value));
+		if(datacell->priv->paramlist)
+			g_object_ref(datacell->priv->paramlist);
+
+		gda_object_connect_destroy (GDA_OBJECT (datacell->priv->paramlist), 
+				    G_CALLBACK (paramlist_destroyed_cb), datacell);
+		break;
+	case PROP_PARAMLISTSOURCE:
+		datacell->priv->source = GDA_PARAMETER_LIST_SOURCE(g_value_get_pointer(value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -368,13 +406,13 @@ render_text_to_display_from_values (GList *values)
 	gchar *str;
 	
 	while (list) {
-		if (list->data && !gda_value_is_null ((GdaValue *)(list->data)))
+		if (list->data && !gda_value_is_null ((GValue *)(list->data)))
 			allnull = FALSE;
 
 		if (list != values)
 			g_string_append (string, " / ");
 		if (list->data) {
-			str = gda_value_stringify ((GdaValue *)(list->data));
+			str = gda_value_stringify ((GValue *)(list->data));
 			/* TODO: use GdaDataHandler */
 			g_string_append (string, str);
 			g_free (str);
@@ -411,19 +449,13 @@ GtkCellRenderer *
 gnome_db_data_cell_renderer_combo_new (GdaParameterList *paramlist, GdaParameterListSource *source)
 {
 	GObject *obj;
-	GnomeDbDataCellRendererCombo *datacell;
 
 	g_return_val_if_fail (GDA_IS_PARAMETER_LIST (paramlist), NULL);
 	g_return_val_if_fail (source, NULL);
 	g_return_val_if_fail (g_slist_find (paramlist->sources_list, source), NULL);
 
-	obj = g_object_new (GNOME_DB_TYPE_DATA_CELL_RENDERER_COMBO, NULL);
-	datacell = GNOME_DB_DATA_CELL_RENDERER_COMBO (obj);
-
-	datacell->priv->paramlist = paramlist;
-	datacell->priv->source = source;
-	gda_object_connect_destroy (GDA_OBJECT (paramlist), 
-				    G_CALLBACK (paramlist_destroyed_cb), obj);
+	obj = g_object_new (GNOME_DB_TYPE_DATA_CELL_RENDERER_COMBO, "param_list", paramlist, 
+                      "param_list_source", source, NULL);
 	
 	return GTK_CELL_RENDERER (obj);
 }
@@ -439,16 +471,18 @@ gnome_db_data_cell_renderer_combo_get_size (GtkCellRenderer *cell,
 {
 	gint calc_width;
 	gint calc_height;
-	gint expander_size;
 
 	/* get the size as calculated by the GtkCellRendererText */
 	GtkCellRendererClass *text_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_TEXT);
 	(text_class->get_size) (cell, widget, cell_area, x_offset, y_offset, width, height);
 	
 	/* Add more space for the popdown menu symbol */
-	gtk_widget_style_get (widget, "expander_size", &expander_size, NULL);
-	calc_width = (gint) cell->xpad * 2 + expander_size;
-	calc_height = (gint) cell->ypad * 2 + expander_size;
+	if (GNOME_DB_DATA_CELL_RENDERER_COMBO (cell)->priv->show_expander) {
+		gint expander_size;
+		gtk_widget_style_get (widget, "expander_size", &expander_size, NULL);
+		calc_width = (gint) cell->xpad * 2 + expander_size;
+		calc_height = (gint) cell->ypad * 2 + expander_size;
+	}
 	
 	if (width)
 		*width += calc_width;
@@ -468,7 +502,7 @@ gnome_db_data_cell_renderer_combo_render (GtkCellRenderer      *cell,
 	
 {
 	GtkStateType state = 0;	
-	gint expander_size;
+	GnomeDbDataCellRendererCombo *combocell = GNOME_DB_DATA_CELL_RENDERER_COMBO (cell);
 
 	/* render the text as for the GtkCellRendererText */
 	GtkCellRendererClass *text_class = g_type_class_peek (GTK_TYPE_CELL_RENDERER_TEXT);
@@ -487,18 +521,22 @@ gnome_db_data_cell_renderer_combo_render (GtkCellRenderer      *cell,
 		else
 			state = GTK_STATE_INSENSITIVE;
 	}
-	gtk_widget_style_get (widget, "expander_size", &expander_size, NULL);
 
-	gtk_paint_expander (widget->style,
-			    window, state,
-			    cell_area, 
-			    widget,
-			    "expander",
-			    cell_area->x + cell_area->width - cell->xpad - expander_size/2.,
-			    cell_area->y + cell_area->height - cell->ypad - expander_size/2. ,
-			    GTK_EXPANDER_EXPANDED);
+	if (combocell->priv->show_expander) {
+		gint expander_size;
+		gtk_widget_style_get (widget, "expander_size", &expander_size, NULL);
+		
+		gtk_paint_expander (widget->style,
+				    window, state,
+				    cell_area, 
+				    widget,
+				    "expander",
+				    cell_area->x + cell_area->width - cell->xpad - expander_size/2.,
+				    cell_area->y + cell_area->height - cell->ypad - expander_size/2. ,
+				    GTK_EXPANDER_EXPANDED);
+	}
 
-	if (GNOME_DB_DATA_CELL_RENDERER_COMBO (cell)->priv->to_be_deleted)
+	if (combocell->priv->to_be_deleted)
 		gtk_paint_hline (widget->style,
 				 window, GTK_STATE_SELECTED,
 				 cell_area, 
