@@ -29,6 +29,7 @@
 #include <libgnomedb/marshal.h>
 #include "gnome-db-data-entry.h"
 #include "gnome-db-entry-string.h"
+#include <libgda/gda-enum-types.h>
 
 #define MAX_ACCEPTED_STRING_LENGTH 500
 
@@ -77,7 +78,9 @@ enum {
 	PROP_0,
 	PROP_VALUE,
 	PROP_VALUE_ATTRIBUTES,
-	PROP_TO_BE_DELETED
+	PROP_TO_BE_DELETED,
+	PROP_DATA_HANDLER,
+	PROP_TYPE
 };
 
 struct _GnomeDbDataCellRendererTextualPrivate
@@ -171,24 +174,32 @@ gnome_db_data_cell_renderer_textual_class_init (GnomeDbDataCellRendererTextualCl
   
 	g_object_class_install_property (object_class,
 					 PROP_VALUE_ATTRIBUTES,
-					 g_param_spec_uint ("value_attributes", NULL, NULL,
-                                                            0, G_MAXUINT, 0, G_PARAM_READWRITE));
+					 g_param_spec_flags ("value_attributes", NULL, NULL, GDA_TYPE_VALUE_ATTRIBUTE,
+                                                            GDA_VALUE_ATTR_NONE, G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_TO_BE_DELETED,
 					 g_param_spec_boolean ("to_be_deleted", NULL, NULL, FALSE,
                                                                G_PARAM_WRITABLE));
-	  
+	g_object_class_install_property(object_class,
+                                  PROP_DATA_HANDLER,
+                                  g_param_spec_object("data_handler", NULL, NULL, GDA_TYPE_DATA_HANDLER,
+                                                      G_PARAM_WRITABLE|G_PARAM_CONSTRUCT_ONLY));
+  g_object_class_install_property(object_class,
+                                  PROP_TYPE,
+                                  g_param_spec_gtype("type", NULL, NULL, G_TYPE_NONE,
+                                                      G_PARAM_WRITABLE|G_PARAM_CONSTRUCT_ONLY));
+  
 	text_cell_renderer_textual_signals [CHANGED] =
 		g_signal_new ("changed",
 			      G_OBJECT_CLASS_TYPE (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GnomeDbDataCellRendererTextualClass, changed),
 			      NULL, NULL,
-			      marshal_VOID__STRING_POINTER,
+			      marshal_VOID__STRING_BOXED,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_STRING,
-			      G_TYPE_POINTER);
+			      G_TYPE_VALUE);
 
 }
 
@@ -309,12 +320,23 @@ gnome_db_data_cell_renderer_textual_set_property (GObject *object,
 		g_object_notify (object, "value");
 		break;
 	case PROP_VALUE_ATTRIBUTES:
-		/*if (g_value_get_uint (value) & GDA_VALUE_ATTR_IS_DEFAULT)
+		/*if (g_value_get_flags (value) & GDA_VALUE_ATTR_IS_DEFAULT)
 		  g_object_set (G_OBJECT (object), "text", "", NULL);*/
 		break;
 	case PROP_TO_BE_DELETED:
 		datacell->priv->to_be_deleted = g_value_get_boolean (value);
 		break;
+	case PROP_DATA_HANDLER:
+		if (datacell->priv->dh)
+			g_object_unref (G_OBJECT (datacell->priv->dh));
+
+		datacell->priv->dh = GDA_DATA_HANDLER(g_value_get_object(value));
+		if (datacell->priv->dh)
+			g_object_ref (G_OBJECT (datacell->priv->dh));
+		break;
+	case PROP_TYPE:
+		datacell->priv->type = g_value_get_gtype(value);
+	break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -343,13 +365,8 @@ gnome_db_data_cell_renderer_textual_new (GdaDataHandler *dh, GType type)
 	GnomeDbDataCellRendererTextual *datacell;
 
 	g_return_val_if_fail (!dh || GDA_IS_DATA_HANDLER (dh), NULL);
-	obj = g_object_new (GNOME_DB_TYPE_DATA_CELL_RENDERER_TEXTUAL, NULL);
-
-	datacell = GNOME_DB_DATA_CELL_RENDERER_TEXTUAL (obj);
-	datacell->priv->dh = dh;
-	if (dh)
-		g_object_ref (G_OBJECT (dh));
-	datacell->priv->type = type;
+	obj = g_object_new (GNOME_DB_TYPE_DATA_CELL_RENDERER_TEXTUAL,
+                      "type", type, "data_handler", dh, NULL);
 
 	return GTK_CELL_RENDERER (obj);
 }
