@@ -57,7 +57,7 @@ static void gnome_db_entry_common_time_start_editing (GtkCellEditable *iface, Gd
 static GtkWidget *create_entry (GnomeDbEntryWrapper *mgwrap);
 static void       real_set_value (GnomeDbEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GnomeDbEntryWrapper *mgwrap);
-static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb);
+static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb);
 static gboolean   expand_in_layout (GnomeDbEntryWrapper *mgwrap);
 static void       set_editable (GnomeDbEntryWrapper *mgwrap, gboolean editable);
 static void       grab_focus (GnomeDbEntryWrapper *mgwrap);
@@ -451,16 +451,16 @@ typedef void (*Callback2) (gpointer, gpointer);
 static gboolean
 focus_out_cb (GtkWidget *widget, GdkEventFocus *event, GnomeDbEntryCommonTime *mgtim)
 {
-	GCallback activ_cb;
-	activ_cb = g_object_get_data (G_OBJECT (widget), "_activ_cb");
-	g_assert (activ_cb);
-	((Callback2)activ_cb) (widget, mgtim);
+	GCallback activate_cb;
+	activate_cb = g_object_get_data (G_OBJECT (widget), "_activate_cb");
+	g_assert (activate_cb);
+	((Callback2)activate_cb) (widget, mgtim);
 
 	return FALSE;
 }
 
 static void
-connect_signals (GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb)
+connect_signals (GnomeDbEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb)
 {
 	GnomeDbEntryCommonTime *mgtim;
 	GType type;
@@ -472,21 +472,21 @@ connect_signals (GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback acti
 	type = gnome_db_data_entry_get_value_type (GNOME_DB_DATA_ENTRY (mgtim));
 
 	if ((type == G_TYPE_DATE) || (type == GDA_TYPE_TIMESTAMP)) {
-		g_object_set_data (G_OBJECT (mgtim->priv->entry_date), "_activ_cb", activ_cb);
+		g_object_set_data (G_OBJECT (mgtim->priv->entry_date), "_activate_cb", activate_cb);
 		g_signal_connect (G_OBJECT (mgtim->priv->entry_date), "changed",
-				  modif_cb, mgwrap);
+				  modify_cb, mgwrap);
 		g_signal_connect (G_OBJECT (mgtim->priv->entry_date), "activate",
-				  activ_cb, mgwrap);
+				  activate_cb, mgwrap);
 		g_signal_connect (G_OBJECT (mgtim->priv->entry_date), "focus-out-event",
 				  G_CALLBACK (focus_out_cb), mgtim);
 	}
 
 	if ((type == GDA_TYPE_TIME) || (type == GDA_TYPE_TIMESTAMP)) {
-		g_object_set_data (G_OBJECT (mgtim->priv->entry_time), "_activ_cb", activ_cb);
+		g_object_set_data (G_OBJECT (mgtim->priv->entry_time), "_activate_cb", activate_cb);
 		g_signal_connect (G_OBJECT (mgtim->priv->entry_time), "changed",
-				  modif_cb, mgwrap);
+				  modify_cb, mgwrap);
 		g_signal_connect (G_OBJECT (mgtim->priv->entry_time), "activate",
-				  activ_cb, mgwrap);
+				  activate_cb, mgwrap);
 		g_signal_connect (G_OBJECT (mgtim->priv->entry_time), "focus-out-event",
 				  G_CALLBACK (focus_out_cb), mgtim);
 	}
