@@ -35,13 +35,13 @@ static void gnome_db_entry_cidr_finalize (GObject   * object);
 static GtkWidget *create_entry (GnomeDbEntryWrapper *mgwrap);
 static void       real_set_value (GnomeDbEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GnomeDbEntryWrapper *mgwrap);
-static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb);
+static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb);
 static gboolean   expand_in_layout (GnomeDbEntryWrapper *mgwrap);
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
 
-/* usefull static functions */
+/* useful static functions */
 static gint     get_ip_nb_bits (GnomeDbEntryCidr *mgcidr);
 static gint     get_mask_nb_bits (GnomeDbEntryCidr *mgcidr);
 static gboolean get_complete_value (GnomeDbEntryCidr *mgcidr, gboolean target_mask, gulong *result);
@@ -568,7 +568,7 @@ real_get_value (GnomeDbEntryWrapper *mgwrap)
 }
 
 static void
-connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb)
+connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb)
 {
 	GnomeDbEntryCidr *mgcidr;
 	gint i;
@@ -578,10 +578,10 @@ connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ
 	g_return_if_fail (mgcidr->priv);
 
 	for (i=0; i<4; i++) {
-		g_signal_connect (G_OBJECT (mgcidr->priv->ip[i]), "changed", modif_cb, mgwrap);
-		g_signal_connect (G_OBJECT (mgcidr->priv->mask[i]), "changed", modif_cb, mgwrap);
-		g_signal_connect (G_OBJECT (mgcidr->priv->ip[i]), "activate", activ_cb, mgwrap);
-		g_signal_connect (G_OBJECT (mgcidr->priv->mask[i]), "activate", activ_cb, mgwrap);
+		g_signal_connect (G_OBJECT (mgcidr->priv->ip[i]), "changed", modify_cb, mgwrap);
+		g_signal_connect (G_OBJECT (mgcidr->priv->mask[i]), "changed", modify_cb, mgwrap);
+		g_signal_connect (G_OBJECT (mgcidr->priv->ip[i]), "activate", activate_cb, mgwrap);
+		g_signal_connect (G_OBJECT (mgcidr->priv->mask[i]), "activate", activate_cb, mgwrap);
 	}
 }
 
