@@ -44,7 +44,7 @@ static void gnome_db_entry_pict_finalize (GObject *object);
 static GtkWidget *create_entry (GnomeDbEntryWrapper *mgwrap);
 static void       real_set_value (GnomeDbEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GnomeDbEntryWrapper *mgwrap);
-static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb);
+static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb);
 static gboolean   expand_in_layout (GnomeDbEntryWrapper *mgwrap);
 static void       set_editable (GnomeDbEntryWrapper *mgwrap, gboolean editable);
 static gboolean   value_is_equal_to (GnomeDbEntryWrapper *mgwrap, const GValue *value);
@@ -426,7 +426,7 @@ real_get_value (GnomeDbEntryWrapper *mgwrap)
 }
 
 static void
-connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb)
+connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb)
 {
 	/* doe nothing because we manullay call gnome_db_entry_wrapper_contents_changed() */
 }
