@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999 - 2006 The GNOME Foundation.
+ * Copyright (C) 1999 - 2007 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -24,7 +24,9 @@
 #include "gnome-db-decl.h"
 #include <libgda/gda-config.h>
 #include <libgnomedb/gnome-db-data-source-selector.h>
-#include <libgnomedb/gnome-db-dsn-config-druid.h>
+#ifdef HAVE_GTKTWOTEN
+#include <libgnomedb/gnome-db-dsn-assistant.h>
+#endif
 #include <glib/gi18n-lib.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-util.h>
@@ -66,16 +68,15 @@ enum {
 
 static GObjectClass *parent_class = NULL;
 
-
+#ifdef HAVE_GTKTWOTEN
 static void
-druid_finished_cb (GnomeDbDsnConfigDruid *druid, gboolean error, GnomeDbLogin *login);
+assistant_finished_cb (GnomeDbDsnAssistant *assistant, gboolean error, GnomeDbLogin *login);
 static void
 add_dsn_cb (GtkButton *button, GnomeDbLogin *login);
+#endif
 static void
 dsn_entry_changed_cb (GnomeDbDataSourceSelector *sel, GnomeDbLogin *login);
 
-
-
 /*
  * Private functions
  */
@@ -150,12 +151,16 @@ gnome_db_login_init (GnomeDbLogin *login, GnomeDbLoginClass *klass)
 			  G_CALLBACK (dsn_entry_changed_cb), login);
 			  
 	/* Create the DSN add button */
+#ifdef HAVE_GTKTWOTEN
 	login->priv->create_dsn_button = gnome_db_new_button_widget_from_stock (GTK_STOCK_ADD);
 	g_signal_connect (G_OBJECT (login->priv->create_dsn_button), "clicked",
 			  G_CALLBACK (add_dsn_cb), login);
 	gtk_widget_hide (login->priv->create_dsn_button); /* Hide the create DSN button */
 	gtk_table_attach (GTK_TABLE (table), login->priv->create_dsn_button, 2, 3, 0, 1,
 			  GTK_FILL, GTK_FILL, 0, 0);
+#else
+	login->priv->create_dsn_button = NULL;
+#endif
 			  
 	/* Create the Username Entry*/
 	label = gnome_db_new_label_widget (_("Username:"));
@@ -277,40 +282,27 @@ gnome_db_login_get_type (void)
 	return type;
 }
 
+#ifdef HAVE_GTKTWOTEN
 static void
-druid_finished_cb (GnomeDbDsnConfigDruid *druid, gboolean error, GnomeDbLogin *login)
+assistant_finished_cb (GnomeDbDsnAssistant *assistant, gboolean error, GnomeDbLogin *login)
 {
-	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (druid)));
+	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (assistant)));
 	gtk_widget_set_sensitive (gtk_widget_get_toplevel (GTK_WIDGET (login)), TRUE);
 }
 
 static void
 add_dsn_cb (GtkButton *button, GnomeDbLogin *login)
 {
-	GtkWidget *druid, *dialog;
-	GdkPixbuf *icon;
+	GtkWidget *assistant;
 
 	gtk_widget_set_sensitive (gtk_widget_get_toplevel (GTK_WIDGET (login)), FALSE);
 
-	/* create the dialog */
-	dialog = gtk_dialog_new_with_buttons (_("New data source"),
-					      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (login))),
-					      0, NULL);
-	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
-	if (icon) {
-		gtk_window_set_icon (GTK_WINDOW (dialog), icon);
-		g_object_unref (icon);
-	}
-
-	druid = gnome_db_dsn_config_druid_new ();
-	g_signal_connect (G_OBJECT (druid), "finished",
-			  G_CALLBACK (druid_finished_cb), login);
-	gtk_widget_show (druid);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), druid, TRUE, TRUE, 6);
-
-	/* run the dialog */
-	gtk_widget_show (dialog);
+	assistant = gnome_db_dsn_assistant_new ();
+	g_signal_connect (G_OBJECT (assistant), "finished",
+			  G_CALLBACK (assistant_finished_cb), login);
+	gtk_widget_show (assistant);
 }
+#endif
 
 static void
 dsn_entry_changed_cb (GnomeDbDataSourceSelector *sel, GnomeDbLogin *login)
@@ -334,7 +326,6 @@ dsn_entry_changed_cb (GnomeDbDataSourceSelector *sel, GnomeDbLogin *login)
 	}
 }
 
-
 /**
  * gnome_db_login_new
  * @dsn:
@@ -368,7 +359,7 @@ gnome_db_login_get_dsn (GnomeDbLogin *login)
 	if (login->priv->dsn_name)
 		return (const gchar *) login->priv->dsn_name;
 
-	return gnome_db_data_source_selector_get_dsn (login->priv->dsn_entry);
+	return gnome_db_data_source_selector_get_dsn (GNOME_DB_DATA_SOURCE_SELECTOR (login->priv->dsn_entry));
 }
 
 /**
@@ -393,7 +384,8 @@ gnome_db_login_set_dsn (GnomeDbLogin *login, const gchar *dsn)
 		if (src->password)
 			gtk_entry_set_text (GTK_ENTRY (login->priv->password_entry), src->password);
 		gda_data_source_info_free (src);
-		gnome_db_data_source_selector_set_dsn (login->priv->dsn_entry, dsn);
+		gnome_db_data_source_selector_set_dsn (GNOME_DB_DATA_SOURCE_SELECTOR (login->priv->dsn_entry), 
+						       dsn);
 	}
 }
 
@@ -472,6 +464,9 @@ gnome_db_login_set_enable_create_button (GnomeDbLogin *login, gboolean enable)
 	if (login->priv->hiding_button != enable)
 		return;
 
+	if (!login->priv->create_dsn_button)
+		return;
+
 	login->priv->hiding_button = !enable;
 	if (enable) {
 		if (!login->priv->hiding_dsn)
@@ -514,13 +509,14 @@ gnome_db_login_set_show_dsn_selector (GnomeDbLogin *login, gboolean show)
 	if (show) {
 		gtk_widget_show (login->priv->dsn_entry);
 		gtk_widget_show (login->priv->dsn_label);
-		if (!login->priv->hiding_button)
+		if (login->priv->create_dsn_button && !login->priv->hiding_button)
 			gtk_widget_show (login->priv->create_dsn_button);
 	}
 	else {
 		gtk_widget_hide (login->priv->dsn_entry);
 		gtk_widget_hide (login->priv->dsn_label);
-		gtk_widget_hide (login->priv->create_dsn_button);
+		if (login->priv->create_dsn_button)
+			gtk_widget_hide (login->priv->create_dsn_button);
 	}
 }
 
