@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999 - 2005 The GNOME Foundation.
+ * Copyright (C) 1999 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -51,12 +51,15 @@ show_providers (GnomeDbProviderSelector *selector)
 {
 	GdaDataModel *model;
 	GSList *list;
+	GValue *tmpval;
 
 	model = gda_config_get_provider_model ();
 	gnome_db_combo_set_model (GNOME_DB_COMBO (selector), model, 1, cols);
-	list = g_slist_append (NULL, gda_value_new_string ("SQLite"));
+
+	g_value_set_string (tmpval = gda_value_new (G_TYPE_STRING), "SQLite");
+	list = g_slist_append (NULL, tmpval);
 	gnome_db_combo_set_values_ext (GNOME_DB_COMBO (selector), list, cols);
-	gda_value_free ((GdaValue *)(list->data));
+	gda_value_free ((GValue *)(list->data));
 	g_slist_free (list);
 	g_object_unref (model);
 }
@@ -155,7 +158,7 @@ gnome_db_provider_selector_get_selected_provider (GnomeDbProviderSelector *selec
 	g_return_val_if_fail (GNOME_DB_IS_PROVIDER_SELECTOR (selector), NULL);
 	list = gnome_db_combo_get_values (GNOME_DB_COMBO (selector));
 	if (list) {
-		str = gda_value_get_string ((GdaValue *)(list->data));
+		str = g_value_get_string ((GValue *)(list->data));
 		g_slist_free (list);
 		return str;
 	}
@@ -178,16 +181,65 @@ gnome_db_provider_selector_set_selected_provider (GnomeDbProviderSelector *selec
 {
 	GSList *list;
 	gboolean retval;
+	GValue *tmpval;
 
 	g_return_val_if_fail (GNOME_DB_IS_PROVIDER_SELECTOR (selector), FALSE);
 
 	if (provider && *provider)
-		list = g_slist_append (NULL, gda_value_new_string (provider));
+		g_value_set_string (tmpval = gda_value_new (G_TYPE_STRING), provider);
 	else
-		list = g_slist_append (NULL, gda_value_new_string ("SQLite"));
+		g_value_set_string (tmpval = gda_value_new (G_TYPE_STRING), "SQLite");
+
+	list = g_slist_append (NULL, tmpval);
 	retval = gnome_db_combo_set_values_ext (GNOME_DB_COMBO (selector), list, cols);
-	gda_value_free ((GdaValue *)(list->data));
+	gda_value_free ((GValue *)(list->data));
 	g_slist_free (list);
 
 	return retval;
 }
+
+/**
+ * gnome_db_provider_selector_get_selected_provider_obj
+ * @selector: a #GnomeDbProviderSelector widget
+ *
+ * Get the selected provider as a #GdaServerProvider object
+ *
+ * Returns: a new #GdaServerProvider or %NULL if an error occurred
+ */
+GdaServerProvider *
+gnome_db_provider_selector_get_selected_provider_obj (GnomeDbProviderSelector *selector)
+{
+	GdaProviderInfo *info;
+	GModule *handle;
+	GdaServerProvider  *(*plugin_create_provider) (void);
+	GdaServerProvider *prov;
+	const gchar *pname;
+		
+	g_return_val_if_fail (GNOME_DB_IS_PROVIDER_SELECTOR (selector), NULL);
+
+	pname = gnome_db_provider_selector_get_selected_provider (selector);
+	info = gda_config_get_provider_by_name (pname);
+	if (!info) {
+		g_warning ("Can't find provider '%s'", pname);
+		return NULL;
+	}
+
+	handle = g_module_open (info->location, G_MODULE_BIND_LAZY);;
+	if (!handle) {
+		g_warning ("Can't load provider '%s''s module: %s", pname, g_module_error ());
+		return NULL;
+	}
+
+	g_module_symbol (handle, "plugin_create_provider",
+			 (gpointer) &plugin_create_provider);
+	if (!plugin_create_provider) {
+		g_warning ("Provider '%s' does not implement entry function", pname);
+		return NULL;
+	}
+
+	prov = plugin_create_provider ();
+	if (!prov)
+		g_warning ("Could not create GdaServerProvider object from plugin ('%s' provider)",
+			   pname);
+	return prov;
+}
